markuptools.MarkupInventory
===========================

.. inheritance-diagram:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory
   :private-bases:

.. autoclass:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.inventory_name

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.append

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.extend

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__contains__

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__repr__

   .. note:: Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__str__

   .. note:: Inherited from `__builtin__.object`
